@@ -1,4 +1,4 @@
-"""asyncprawcore: Low-level communication layer for PRAW 4+."""
+"""asyncprawcore: Low-level asynchronous communication layer for Async PRAW 7+."""
 
 import logging
 from .auth import (  # noqa
@@ -15,5 +15,4 @@ from .exceptions import *  # noqa
 from .requestor import Requestor  # noqa
 from .sessions import Session, session  # noqa
 
-
 logging.getLogger(__package__).addHandler(logging.NullHandler())
